//
//  JobsViewController.m
//  PLS Mobile
//
//  Created by Daniel Workman on 25/04/2013.
//  Copyright (c) 2013 Daniel Workman. All rights reserved.
//

#import "JobsViewController.h"
#import "JobDetailsViewController.h"
#import "ASIHTTPRequest.h"
#import "ASIFormDataRequest.h"
#import "SBJson.h"
#import "MBProgressHUD.h"
#import "GlobalObjects.h"

@interface JobsViewController ()

@end

@implementation JobsViewController

NSMutableArray* jobsArray;

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    jobsArray = [[NSMutableArray alloc] init];
    
    // Start request
    NSString *urlString = [[NSUserDefaults standardUserDefaults] stringForKey:@"database_url"];
    ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:[NSURL URLWithString:urlString]];
    [request setPostValue:@"jobs" forKey:@"request"];
    [request setPostValue:[GlobalObjects getCurrentUser] forKey:@"username"];
    [request setPostValue:[NSString stringWithFormat:@"%d", self.status] forKey:@"status"];
    [request setDelegate:self];
    [request startAsynchronous];
    
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.labelText = @"Retrieving jobs...";

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)requestFinished:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    
    if (request.responseStatusCode == 200) {
        NSString *responseString = [request responseString];
        NSDictionary *responseDict = [responseString JSONValue];
        
        for (NSString *key in responseDict) {
            NSDictionary *job = [responseDict objectForKey:key];
            [jobsArray addObject:job];
        }
        
        [self.jobsTable reloadData];
    } else {
        ALERT(@"Request Failed", request.responseStatusMessage);
    }
}

- (void)requestFailed:(ASIHTTPRequest *)request
{
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    ALERT(@"Request Failed", [[request error] localizedDescription]);
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [jobsArray count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *cellIdentifier = @"JobCell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier forIndexPath:indexPath];
    
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellIdentifier];
    }
    
    NSDictionary* dict = [jobsArray objectAtIndex:indexPath.row];
    NSInteger type = [[dict objectForKey:@"type"] integerValue];

    cell.detailTextLabel.text = [GlobalObjects jobTypeToString:type];
    cell.textLabel.text = [dict objectForKey:@"description"];
    cell.tag = [[dict objectForKey:@"id"] integerValue];

    return cell;
}

- (NSString *)tableView:(UITableView *)tableView titleForFooterInSection:(NSInteger)section
{
    if ([jobsArray count] <= 0)
    {
        return @"There are no jobs to display";
    }
    
    return @"";
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([[segue identifier] isEqualToString:@"JobDetails"]) {
        
        JobDetailsViewController *vc = [segue destinationViewController];

        NSIndexPath *index = [self.jobsTable indexPathForSelectedRow];
        [vc setJobId:[[self.jobsTable cellForRowAtIndexPath:index] tag]];
        [vc setStatus: self.status];
    }
}

/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{    
    // Navigation logic may go here. Create and push another view controller.
    /*
     <#DetailViewController#> *detailViewController = [[<#DetailViewController#> alloc] initWithNibName:@"<#Nib name#>" bundle:nil];
     // ...
     // Pass the selected object to the new view controller.
     [self.navigationController pushViewController:detailViewController animated:YES];
     */
}

@end
