--
-- Clear all current tables
--

DROP TABLE IF EXISTS engineer;
DROP TABLE IF EXISTS site;
DROP TABLE IF EXISTS atm;
DROP TABLE IF EXISTS part;
DROP TABLE IF EXISTS job;
DROP TABLE IF EXISTS job_parts;
DROP TABLE IF EXISTS job_documents;

--
-- Create our tables
--

CREATE TABLE engineer(
  id INTEGER NOT NULL AUTO_INCREMENT,
  username VARCHAR(100) NOT NULL,
  pw_hash VARCHAR(100) NOT NULL,
  pw_salt VARCHAR(100) NOT NULL,
  forename VARCHAR(100),
  surname VARCHAR(100),
  PRIMARY KEY(id)
);

CREATE TABLE site(
  id INTEGER NOT NULL AUTO_INCREMENT,
  name VARCHAR(255) NOT NULL,
  addressLine1 VARCHAR(100),
  addressLine2 VARCHAR(100),
  town VARCHAR(50),
  county VARCHAR(50),
  postcode VARCHAR(50),
  phone VARCHAR(50),
  PRIMARY KEY(id)
 );

CREATE TABLE atm(
  id INTEGER NOT NULL AUTO_INCREMENT,
  make VARCHAR(255) NOT NULL,
  model VARCHAR(255) NOT NULL,
  notes TEXT,
  PRIMARY KEY(id)
);
  
CREATE TABLE part(
  id INTEGER NOT NULL,
  make VARCHAR(100) NOT NULL,
  model VARCHAR(100) NOT NULL,
  description VARCHAR(1000),
  PRIMARY KEY(id)
);

CREATE TABLE job(
  id INTEGER NOT NULL AUTO_INCREMENT,
  description VARCHAR(255),
  engineer_id INTEGER NOT NULL,
  site_id INTEGER NOT NULL,
  atm_id INTEGER NOT NULL,
  type TINYINT(3) NOT NULL, # install, repair, uplift...
  details TEXT,
  parking TEXT,
  status TINYINT(3) NOT NULL, # waiting, accepted, completed, aborted...
  creation_date DATETIME NOT NULL,
  completion_date DATETIME,
  closing_report TEXT,
  PRIMARY KEY(id),
  FOREIGN KEY(engineer_id) REFERENCES engineer(id),
  FOREIGN KEY(site_id) REFERENCES site(id),
  FOREIGN KEY(atm_id) REFERENCES atm(id)
);

CREATE TABLE job_parts(
  job_id INTEGER NOT NULL,
  part_id INTEGER NOT NULL,
  quantity SMALLINT(5) NOT NULL,
  PRIMARY KEY(job_id, part_id),
  FOREIGN KEY(job_id) REFERENCES job(id),
  FOREIGN KEY(part_id) REFERENCES part(id)
);

CREATE TABLE job_documents(
  job_id INTEGER NOT NULL,
  document VARCHAR(1000), # name of file on server
  FOREIGN KEY(job_id) REFERENCES job(id)
);

--
-- Create some sample data to seed our database...
--

INSERT INTO engineer VALUES(1, 'workmandan', '$2a$10$wSsf71d.cYN8874rBiVEzun4Wt3b8A7Pdwid4DAyR1T/Kuk9IGmNq', '$2a$10$wSsf71d.cYN8874rBiVEzu', 'Dan', 'Workman');

INSERT INTO site VALUES(1, 'Slug & Lettuce', '34 High Street', '', 'Oldtown', 'Kent', 'K1 3AA', '01287 776221');
INSERT INTO site VALUES(2, 'Gala Casino', 'Unit 13', 'New Industrial Estate', 'Plymouth', 'Devon', 'PL4 8GH', '01983 221223');
INSERT INTO site VALUES(3, 'Bargains Newsagent', '24 Cryws Road', 'Cathays', 'Cardiff', '', 'CF24 3AS', '02920 221229');

INSERT INTO atm VALUES(1, 'Triton', '9100', 'Here are some example notes to prove we can view them correctly.');
INSERT INTO atm VALUES(2, 'Triton', '9600', '');
INSERT INTO atm VALUES(3, 'Triton', 'FT5000', '');

INSERT INTO part VALUES(1, 'Triton', 'KP300', 'Keypad');
INSERT INTO part VALUES(2, 'Triton', 'PR990', 'Receipt Printer');
INSERT INTO part VALUES(3, 'Triton', 'HT33', 'High Topper');

INSERT INTO job VALUES(1, 'Gala Casino, Plymouth', 1, 2, 2, 1, 'Customer reports a faulty keypad', 'Obvious large carpark (free)', 0, '2013-04-12', null, ''); 
INSERT INTO job VALUES(2, 'Bargains Newsagent, Cardiff', 1, 3, 1, 2, 'No longer a customer', 'Street opposite provides free parking', 0, '2013-04-14', null, ''); 
INSERT INTO job VALUES(3, 'Bargains Newsagent, Cardiff ACC', 1, 3, 1, 2, 'No longer a customer', 'Street opposite provides free parking', 1, '2013-04-14', null, ''); 
INSERT INTO job VALUES(4, 'Bargains Newsagent, Cardiff COMP', 1, 3, 1, 2, 'No longer a customer', 'Street opposite provides free parking', 2, '2013-04-14', null, ''); 
